@tailwind base;
@tailwind components;
@tailwind utilities;

footer {
  background-color: hsl(var(--nextra-bg)) !important;
}

@layer base {
  :root {
    /* Main colors - Terracotta */
    --primary: 10 68% 63%;
    --primary-foreground: 10 10% 98%;

    /* Secondary colors */
    --secondary: 0 0% 100%;
    --secondary-foreground: 10 15% 15%;

    /* Accent colors - complementary to Terracotta */
    --accent: 190 40% 45%;
    --accent-foreground: 190 40% 98%;

    /* Background colors */
    --background: 0 0% 100%;
    --foreground: 0 0% 12%;

    /* Card and surface colors */
    --card: 10 30% 98%;
    --card-foreground: 0 0% 12%;

    /* Muted elements - very light Terracotta */
    --muted: 10 20% 96%;
    --muted-foreground: 10 15% 45%;

    /* Border colors - light Terracotta */
    --border: 10 15% 88%;

    /* Input elements */
    --input: 10 15% 88%;

    /* Ring/focus colors */
    --ring: 10 68% 63%;

    /* State colors */
    --success: 142 72% 29%;
    --warning: 38 92% 50%;
    --error: 0 84% 60%;
    --info: 208 79% 51%;

    /* Destructive actions */
    --destructive: 0 84% 60%;
    --destructive-foreground: 0 0% 98%;

    /* Radius */
    --radius: 0.5rem;

    /* Charts - Terracotta palette */
    --chart-1: 10 68% 63%;
    --chart-2: 20 65% 60%;
    --chart-3: 30 60% 58%;
    --chart-4: 40 55% 65%;
    --chart-5: 0 70% 55%;
  }

  .dark {
    /* Main colors - Terracotta */
    --primary: 10 68% 63%;
    --primary-foreground: 10 10% 98%;

    /* Secondary colors */
    --secondary: 0 0% 9%;
    --secondary-foreground: 10 10% 98%;

    /* Accent colors - complementary to Terracotta */
    --accent: 190 40% 50%;
    --accent-foreground: 190 40% 98%;

    /* Background colors */
    --background: 0 0% 9%;
    --foreground: 0 0% 98%;

    /* Card and surface colors */
    --card: 10 15% 12%;
    --card-foreground: 0 0% 98%;

    /* Muted elements - darker Terracotta */
    --muted: 10 15% 15%;
    --muted-foreground: 10 10% 65%;

    /* Border colors - dark Terracotta */
    --border: 10 20% 25%;

    /* Input elements */
    --input: 10 20% 25%;

    /* Ring/focus colors */
    --ring: 10 68% 63%;

    /* State colors */
    --success: 142 72% 35%;
    --warning: 38 92% 50%;
    --error: 0 84% 60%;
    --info: 208 79% 51%;

    /* Destructive actions */
    --destructive: 0 84% 60%;
    --destructive-foreground: 0 0% 98%;

    /* Radius */
    --radius: 0.5rem;

    /* Charts - Terracotta palette */
    --chart-1: 10 68% 63%;
    --chart-2: 20 65% 60%;
    --chart-3: 30 60% 58%;
    --chart-4: 40 55% 65%;
    --chart-5: 0 70% 55%;
  }
}