export default {
    index: {
      title: 'MCP Community',
      type: 'page',
      display: "hidden",
      theme: {
        layout: "raw",
        timestamp: false,
      },
    },
    docs: {
      type: 'page',
      title: 'Docs'
    },
    "self-hosting": {
      type: 'page',
      title: 'Self Hosting'
    },
    "waitlist": {
      type: 'page',
      title: 'Waitlist',
    }
}