import { DocsMenuSeparator } from "@/components/DocsMenuSeparator";

export default {
  "-- Docs Menu Separator": {
    type: "separator",
    title: <DocsMenuSeparator />,
  },
  index: "Overview",
};