import { DocsMenuSeparator } from "@/components/DocsMenuSeparator";

export default {
  "-- Docs Menu Separator": {
    type: "separator",
    title: <DocsMenuSeparator />,
  },
  index: "Overview",
  quickstart: "Quickstart",
  "open-source": "Open Source",
  "-- Server Separator": {
    type: "separator",
    title: "MCP Server",
  },
  server: "Coming soon...",
  "-- Deployment Separator": {
    type: "separator",
    title: "Deployment",
  },
  deployment: "Coming soon...",
  "-- Client Separator": {
    type: "separator",
    title: "MCP Client",
  },
  client: "Coming soon...",
};
